==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/BRANCHCONDITIONDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour BRANCHCONDITIONDETAILS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="BRANCHCONDITIONDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BRANCHCONDITION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BRANCHPATTERN"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BRANCHGOTO"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLEARPREVVALUES"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BRANCHCONDITIONDETAILS_Type", propOrder = {
    "branchcondition",
    "branchpattern",
    "branchgoto",
    "clearprevvalues"
})
public class BRANCHCONDITIONDETAILS_Type {

    @XmlElement(name = "BRANCHCONDITION", required = true)
    protected String branchcondition;
    @XmlElement(name = "BRANCHPATTERN", required = true)
    protected String branchpattern;
    @XmlElement(name = "BRANCHGOTO")
    protected long branchgoto;
    @XmlElement(name = "CLEARPREVVALUES", required = true)
    protected String clearprevvalues;

    /**
     * Obtient la valeur de la propriété branchcondition.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBRANCHCONDITION() {
        return branchcondition;
    }

    /**
     * Définit la valeur de la propriété branchcondition.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBRANCHCONDITION(String value) {
        this.branchcondition = value;
    }

    /**
     * Obtient la valeur de la propriété branchpattern.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBRANCHPATTERN() {
        return branchpattern;
    }

    /**
     * Définit la valeur de la propriété branchpattern.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBRANCHPATTERN(String value) {
        this.branchpattern = value;
    }

    /**
     * Obtient la valeur de la propriété branchgoto.
     * 
     */
    public long getBRANCHGOTO() {
        return branchgoto;
    }

    /**
     * Définit la valeur de la propriété branchgoto.
     * 
     */
    public void setBRANCHGOTO(long value) {
        this.branchgoto = value;
    }

    /**
     * Obtient la valeur de la propriété clearprevvalues.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCLEARPREVVALUES() {
        return clearprevvalues;
    }

    /**
     * Définit la valeur de la propriété clearprevvalues.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCLEARPREVVALUES(String value) {
        this.clearprevvalues = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/BRANCHCONDITIONDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for BRANCHCONDITIONDETAILS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="BRANCHCONDITIONDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BRANCHCONDITION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BRANCHPATTERN"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BRANCHGOTO"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLEARPREVVALUES"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BRANCHCONDITIONDETAILS_Type", propOrder = {
    "branchcondition",
    "branchpattern",
    "branchgoto",
    "clearprevvalues"
})
public class BRANCHCONDITIONDETAILS_Type {

    @XmlElement(name = "BRANCHCONDITION", required = true)
    protected String branchcondition;
    @XmlElement(name = "BRANCHPATTERN", required = true)
    protected String branchpattern;
    @XmlElement(name = "BRANCHGOTO")
    protected long branchgoto;
    @XmlElement(name = "CLEARPREVVALUES", required = true)
    protected String clearprevvalues;

    /**
     * Gets the value of the branchcondition property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBRANCHCONDITION() {
        return branchcondition;
    }

    /**
     * Sets the value of the branchcondition property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBRANCHCONDITION(String value) {
        this.branchcondition = value;
    }

    /**
     * Gets the value of the branchpattern property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBRANCHPATTERN() {
        return branchpattern;
    }

    /**
     * Sets the value of the branchpattern property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBRANCHPATTERN(String value) {
        this.branchpattern = value;
    }

    /**
     * Gets the value of the branchgoto property.
     * 
     */
    public long getBRANCHGOTO() {
        return branchgoto;
    }

    /**
     * Sets the value of the branchgoto property.
     * 
     */
    public void setBRANCHGOTO(long value) {
        this.branchgoto = value;
    }

    /**
     * Gets the value of the clearprevvalues property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCLEARPREVVALUES() {
        return clearprevvalues;
    }

    /**
     * Sets the value of the clearprevvalues property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCLEARPREVVALUES(String value) {
        this.clearprevvalues = value;
    }

}
